==> kubernetes-model-core-6.3.0-sources.jar: io/fabric8/kubernetes/api/model/SessionAffinityConfigFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SessionAffinityConfigFluentImpl<A extends SessionAffinityConfigFluent<A>> extends BaseFluent<A> implements SessionAffinityConfigFluent<A>{
  public SessionAffinityConfigFluentImpl() {
  }
  public SessionAffinityConfigFluentImpl(SessionAffinityConfig instance) {
    this.withClientIP(instance.getClientIP()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private ClientIPConfigBuilder clientIP;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildClientIP instead.
   * @return The buildable object.
   */
  @Deprecated
  public ClientIPConfig getClientIP() {
    return this.clientIP!=null ?this.clientIP.build():null;
  }
  public ClientIPConfig buildClientIP() {
    return this.clientIP!=null ?this.clientIP.build():null;
  }
  public A withClientIP(ClientIPConfig clientIP) {
    _visitables.get("clientIP").remove(this.clientIP);
    if (clientIP!=null){ this.clientIP= new ClientIPConfigBuilder(clientIP); _visitables.get("clientIP").add(this.clientIP);} else { this.clientIP = null; _visitables.get("clientIP").remove(this.clientIP); } return (A) this;
  }
  public Boolean hasClientIP() {
    return this.clientIP != null;
  }
  public A withNewClientIP(Integer timeoutSeconds) {
    return (A)withClientIP(new ClientIPConfig(timeoutSeconds));
  }
  public SessionAffinityConfigFluent.ClientIPNested<A> withNewClientIP() {
    return new SessionAffinityConfigFluentImpl.ClientIPNestedImpl();
  }
  public SessionAffinityConfigFluent.ClientIPNested<A> withNewClientIPLike(ClientIPConfig item) {
    return new SessionAffinityConfigFluentImpl.ClientIPNestedImpl(item);
  }
  public SessionAffinityConfigFluent.ClientIPNested<A> editClientIP() {
    return withNewClientIPLike(getClientIP());
  }
  public SessionAffinityConfigFluent.ClientIPNested<A> editOrNewClientIP() {
    return withNewClientIPLike(getClientIP() != null ? getClientIP(): new ClientIPConfigBuilder().build());
  }
  public SessionAffinityConfigFluent.ClientIPNested<A> editOrNewClientIPLike(ClientIPConfig item) {
    return withNewClientIPLike(getClientIP() != null ? getClientIP(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    SessionAffinityConfigFluentImpl that = (SessionAffinityConfigFluentImpl) o;
    if (clientIP != null ? !clientIP.equals(that.clientIP) :that.clientIP != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(clientIP,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (clientIP != null) { sb.append("clientIP:"); sb.append(clientIP + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class ClientIPNestedImpl<N> extends ClientIPConfigFluentImpl<SessionAffinityConfigFluent.ClientIPNested<N>> implements SessionAffinityConfigFluent.ClientIPNested<N>,Nested<N>{
    ClientIPNestedImpl(ClientIPConfig item) {
      this.builder = new ClientIPConfigBuilder(this, item);
    }
    ClientIPNestedImpl() {
      this.builder = new ClientIPConfigBuilder(this);
    }
    ClientIPConfigBuilder builder;
    public N and() {
      return (N) SessionAffinityConfigFluentImpl.this.withClientIP(builder.build());
    }
    public N endClientIP() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-core-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/SessionAffinityConfigFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SessionAffinityConfigFluentImpl<A extends SessionAffinityConfigFluent<A>> extends BaseFluent<A> implements SessionAffinityConfigFluent<A>{
  public SessionAffinityConfigFluentImpl() {
  }
  public SessionAffinityConfigFluentImpl(SessionAffinityConfig instance) {
    if (instance != null) {
      this.withClientIP(instance.getClientIP());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private ClientIPConfigBuilder clientIP;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildClientIP instead.
   * @return The buildable object.
   */
  @Deprecated
  public ClientIPConfig getClientIP() {
    return this.clientIP!=null ?this.clientIP.build():null;
  }
  public ClientIPConfig buildClientIP() {
    return this.clientIP!=null ?this.clientIP.build():null;
  }
  public A withClientIP(ClientIPConfig clientIP) {
    _visitables.get("clientIP").remove(this.clientIP);
    if (clientIP!=null){ this.clientIP= new ClientIPConfigBuilder(clientIP); _visitables.get("clientIP").add(this.clientIP);} else { this.clientIP = null; _visitables.get("clientIP").remove(this.clientIP); } return (A) this;
  }
  public Boolean hasClientIP() {
    return this.clientIP != null;
  }
  public A withNewClientIP(Integer timeoutSeconds) {
    return (A)withClientIP(new ClientIPConfig(timeoutSeconds));
  }
  public SessionAffinityConfigFluentImpl.ClientIPNested<A> withNewClientIP() {
    return new SessionAffinityConfigFluentImpl.ClientIPNestedImpl();
  }
  public SessionAffinityConfigFluentImpl.ClientIPNested<A> withNewClientIPLike(ClientIPConfig item) {
    return new SessionAffinityConfigFluentImpl.ClientIPNestedImpl(item);
  }
  public SessionAffinityConfigFluentImpl.ClientIPNested<A> editClientIP() {
    return withNewClientIPLike(getClientIP());
  }
  public SessionAffinityConfigFluentImpl.ClientIPNested<A> editOrNewClientIP() {
    return withNewClientIPLike(getClientIP() != null ? getClientIP(): new ClientIPConfigBuilder().build());
  }
  public SessionAffinityConfigFluentImpl.ClientIPNested<A> editOrNewClientIPLike(ClientIPConfig item) {
    return withNewClientIPLike(getClientIP() != null ? getClientIP(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SessionAffinityConfigFluentImpl that = (SessionAffinityConfigFluentImpl) o;
    if (!java.util.Objects.equals(clientIP, that.clientIP)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(clientIP,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (clientIP != null) { sb.append("clientIP:"); sb.append(clientIP + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class ClientIPNestedImpl<N> extends ClientIPConfigFluentImpl<SessionAffinityConfigFluentImpl.ClientIPNested<N>> implements SessionAffinityConfigFluentImpl.ClientIPNested<N>,Nested<N>{
    ClientIPNestedImpl(ClientIPConfig item) {
      this.builder = new ClientIPConfigBuilder(this, item);
    }
    ClientIPNestedImpl() {
      this.builder = new ClientIPConfigBuilder(this);
    }
    ClientIPConfigBuilder builder;
    public N and() {
      return (N) SessionAffinityConfigFluentImpl.this.withClientIP(builder.build());
    }
    public N endClientIP() {
      return and();
    }
    
  }
  
}
